@@ -1,14 +1,12 @@
-import os
 import sys
 
 ######################
 ######################
-#       操作系统      #
+#       简写      #
 ######################
 ######################
 
 
-
 def is_win():
     return sys.platform.lower().startswith('win')
 
